# cloudify-python-importer
Bypass issues with import namespaced modules from sys.path folders

Repository is deprecated. Code moved to [cloudify-utilities-plugins-sdk](https://github.com/cloudify-incubator/cloudify-utilities-plugins-sdk/blob/master/cloudify_common_sdk/importer.py).
